{% extends "issues/base.html" %} {% load static %} {% load user %} {% block tab_content %}

# History

Most recent first
Add comment as manual annotation
Now
{# 'body' part of the balloon (separated by a line) #}
{% csrf_token %}
{# 'body' part of the balloon #}
{% for turningpoint in issue.turningpoint_set_all %}
{% if turningpoint.user_id %} {% else %} {% endif %}
{{ turningpoint.get_kind_display }} by {% if turningpoint.user_id %}{{ turningpoint.user|best_displayname }}{% else %}Bugsink{% endif %} {% if turningpoint.user_id == request.user.id %}
{% if turningpoint.kind == 100 %}
{% endif %} {% endif %}
{{ turningpoint.timestamp|date:"j M G:i T" }}
{% if turningpoint.parsed_metadata or turningpoint.triggering_event_id or turningpoint.comment or turningpoint.user_id == request.user.id %} {# the last clause means: editable, hence space must be reserved #}
{# 'body' part of the balloon (separated by a line) #}
{{ turningpoint.comment|linebreaksbr }}
{% if turningpoint.user_id == request.user.id %}
{% csrf_token %} {{ turningpoint.comment }}{# note: we don't actually use {{ form.comments }} here; this means the show-red-on-invalid loop won't work but since everything is valid and we haven't implemented the other parts of that loop that's fine #}
{% endif %}
{% if turningpoint.parsed_metadata %}
{% if turningpoint.kind == 3 %} {# muted #} {% if turningpoint.parsed_metadata.mute_unconditionally %} Muted unconditionally. {% endif %} {% if turningpoint.parsed_metadata.mute_until %} Muted until more than {{ turningpoint.parsed_metadata.mute_until.gte_threshold }} events per {{ turningpoint.parsed_metadata.mute_until.nr_of_periods }} {{ turningpoint.parsed_metadata.mute_until.period_name }}{% if turningpoint.parsed_metadata.mute_until.nr_of_periods != 1 %}s{% endif %} occur. {% endif %} {% if turningpoint.parsed_metadata.mute_for %} Muted for {{ turningpoint.parsed_metadata.mute_for.nr_of_periods }} {{ turningpoint.parsed_metadata.mute_for.period_name }}{% if turningpoint.parsed_metadata.mute_for.nr_of_periods != 1 %}s{% endif %}, i.e. until {{ turningpoint.parsed_metadata.mute_for.unmute_after|date:"j M G:i T" }}. {% endif %} {% elif turningpoint.kind == 5 %} {# unmuted #} {% if turningpoint.parsed_metadata.mute_until %} More than {{ turningpoint.parsed_metadata.mute_until.volume }} events per {{ turningpoint.parsed_metadata.mute_until.nr_of_periods }} {{ turningpoint.parsed_metadata.mute_until.period }}{% if turningpoint.parsed_metadata.mute_until.nr_of_periods != 1 %}s{% endif %} occurred, unmuting the issue. {% endif %} {% if turningpoint.parsed_metadata.mute_for %} An event was observed after the mute-deadline of {{ turningpoint.parsed_metadata.mute_for.unmute_after|date:"j M G:i T" }} and the issue was unmuted. {% endif %} {% endif %} {% if turningpoint.parsed_metadata.resolved_unconditionally %} Marked as 'resolved' (without a specific release-marker). {% endif %} {% if turningpoint.parsed_metadata.resolved_release %} Marked as 'resolved in release {{ turningpoint.parsed_metadata.resolved_release }}'. {% endif %} {% if turningpoint.parsed_metadata.resolve_by_next %} Marked as 'resolved by next release'. {% endif %} {% if turningpoint.parsed_metadata.actual_release %} A new version was released ({{ turningpoint.parsed_metadata.actual_release }}) and the issue was marked as resolved by that specific release. {% endif %}
{% endif %} {% if turningpoint.triggering_event_id %}
Triggering event
{% endif %}
{# 'body' part of the balloon #} {% endif %}
{% endfor %} {% endblock %} {% block extra_js %}
{% endblock %}